slepc-3.18.0 2022-10-01
Report Typos and Errors

# FNEvaluateFunction

Computes the value of the function f(x) for a given x.

### Synopsis

    #include "slepcfn.h"
    PetscErrorCode FNEvaluateFunction(FN fn,PetscScalar x,PetscScalar *y)

Not collective

### Input Parameters

| fn | - the math function context
| x | - the value where the function must be evaluated

### Output Parameter

| y | - the result of f(x)

### Note

Scaling factors are taken into account, so the actual function evaluation will return beta*f(alpha*x).

### See Also

FNEvaluateDerivative(), FNEvaluateFunctionMat(), FNSetScale()

### Level

intermediate

### Location

src/sys/classes/fn/interface/fnbasic.c
Index of all FN routines
Table of Contents for all manual pages
Index of all manual pages